# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class WorkflowInstancesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cancel_workflow_instances(self, workflow_instance_id, **kwargs):  # noqa: E501
        """Cancel workflow instance.  # noqa: E501

        Cancels the workflow instance with the specified ID with a reason. Canceling the workflow instance also cancels the workflow sub-processes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_workflow_instances(workflow_instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_instance_id: The identifier of the workflow instance to be cancelled. (required)
        :param str body: The reason for the cancellation of the workflow instance.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancel_workflow_instances_with_http_info(workflow_instance_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cancel_workflow_instances_with_http_info(workflow_instance_id, **kwargs)  # noqa: E501
            return data

    def cancel_workflow_instances_with_http_info(self, workflow_instance_id, **kwargs):  # noqa: E501
        """Cancel workflow instance.  # noqa: E501

        Cancels the workflow instance with the specified ID with a reason. Canceling the workflow instance also cancels the workflow sub-processes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_workflow_instances_with_http_info(workflow_instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_instance_id: The identifier of the workflow instance to be cancelled. (required)
        :param str body: The reason for the cancellation of the workflow instance.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workflow_instance_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_workflow_instances" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workflow_instance_id' is set
        if ('workflow_instance_id' not in params or
                params['workflow_instance_id'] is None):
            raise ValueError("Missing the required parameter `workflow_instance_id` when calling `cancel_workflow_instances`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_instance_id' in params:
            path_params['workflowInstanceId'] = params['workflow_instance_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances/{workflowInstanceId}/canceled', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_workflow_instances(self, **kwargs):  # noqa: E501
        """Find workflow instances.  # noqa: E501

        Returns workflow instances matching given search criteria.<p>Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned workflow instances satisfy all constraints that are specified in this search criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_workflow_instances(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str business_item_name: The display name of the business item that should be contained by the searched workflows.
        :param str business_item_id: The ID of the business item that should be contained by the searched workflows.
        :param str workflow_definition_id: The ID of the workflow definition.
        :param str workflow_definition_name: The name (or a part of it) of the workflow definition.
        :param str sort_field: The field on which the results are sorted.
        :param str sort_order: The sorting order.
        :param str parent_workflow_instance_id: The ID of the parent workflow instance.
        :return: PagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_workflow_instances_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_workflow_instances_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_workflow_instances_with_http_info(self, **kwargs):  # noqa: E501
        """Find workflow instances.  # noqa: E501

        Returns workflow instances matching given search criteria.<p>Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned workflow instances satisfy all constraints that are specified in this search criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_workflow_instances_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str business_item_name: The display name of the business item that should be contained by the searched workflows.
        :param str business_item_id: The ID of the business item that should be contained by the searched workflows.
        :param str workflow_definition_id: The ID of the workflow definition.
        :param str workflow_definition_name: The name (or a part of it) of the workflow definition.
        :param str sort_field: The field on which the results are sorted.
        :param str sort_order: The sorting order.
        :param str parent_workflow_instance_id: The ID of the parent workflow instance.
        :return: PagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit', 'business_item_name', 'business_item_id', 'workflow_definition_id', 'workflow_definition_name', 'sort_field', 'sort_order', 'parent_workflow_instance_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_workflow_instances" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'business_item_name' in params:
            query_params.append(('businessItemName', params['business_item_name']))  # noqa: E501
        if 'business_item_id' in params:
            query_params.append(('businessItemId', params['business_item_id']))  # noqa: E501
        if 'workflow_definition_id' in params:
            query_params.append(('workflowDefinitionId', params['workflow_definition_id']))  # noqa: E501
        if 'workflow_definition_name' in params:
            query_params.append(('workflowDefinitionName', params['workflow_definition_name']))  # noqa: E501
        if 'sort_field' in params:
            query_params.append(('sortField', params['sort_field']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501
        if 'parent_workflow_instance_id' in params:
            query_params.append(('parentWorkflowInstanceId', params['parent_workflow_instance_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workflow_instance_diagram(self, workflow_instance_id, **kwargs):  # noqa: E501
        """Returns the file representing the diagram of workflow instance identified by the given ID.  # noqa: E501

        Returns the file representing the diagram of workflow instance identified by the given ID. The diagram input stream returned can be null as deployed workflow defintions without graphical notation included don't have a diagram  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_instance_diagram(workflow_instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_instance_id: The ID of the workflow instance to return the diagram for. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_workflow_instance_diagram_with_http_info(workflow_instance_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_workflow_instance_diagram_with_http_info(workflow_instance_id, **kwargs)  # noqa: E501
            return data

    def get_workflow_instance_diagram_with_http_info(self, workflow_instance_id, **kwargs):  # noqa: E501
        """Returns the file representing the diagram of workflow instance identified by the given ID.  # noqa: E501

        Returns the file representing the diagram of workflow instance identified by the given ID. The diagram input stream returned can be null as deployed workflow defintions without graphical notation included don't have a diagram  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_instance_diagram_with_http_info(workflow_instance_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_instance_id: The ID of the workflow instance to return the diagram for. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['workflow_instance_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_instance_diagram" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'workflow_instance_id' is set
        if ('workflow_instance_id' not in params or
                params['workflow_instance_id'] is None):
            raise ValueError("Missing the required parameter `workflow_instance_id` when calling `get_workflow_instance_diagram`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_instance_id' in params:
            path_params['workflowInstanceId'] = params['workflow_instance_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['image/png'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances/{workflowInstanceId}/diagram', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def message_event_received(self, process_instance_id, message_name, **kwargs):  # noqa: E501
        """Pass message event to workflow engine.  # noqa: E501

        Passes the message event to the workflow engine. It will pass on this specific event to the engine with the given name, process instance and variables.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.message_event_received(process_instance_id, message_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str process_instance_id: The ID of an instance of a process. Given process instance should have only one execution running at the time. Otherwise this method will fail. (required)
        :param str message_name: The name of the message to trigger. (required)
        :param MessageEventReceivedRequest body: The properties of the message event to be received.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.message_event_received_with_http_info(process_instance_id, message_name, **kwargs)  # noqa: E501
        else:
            (data) = self.message_event_received_with_http_info(process_instance_id, message_name, **kwargs)  # noqa: E501
            return data

    def message_event_received_with_http_info(self, process_instance_id, message_name, **kwargs):  # noqa: E501
        """Pass message event to workflow engine.  # noqa: E501

        Passes the message event to the workflow engine. It will pass on this specific event to the engine with the given name, process instance and variables.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.message_event_received_with_http_info(process_instance_id, message_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str process_instance_id: The ID of an instance of a process. Given process instance should have only one execution running at the time. Otherwise this method will fail. (required)
        :param str message_name: The name of the message to trigger. (required)
        :param MessageEventReceivedRequest body: The properties of the message event to be received.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['process_instance_id', 'message_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method message_event_received" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'process_instance_id' is set
        if ('process_instance_id' not in params or
                params['process_instance_id'] is None):
            raise ValueError("Missing the required parameter `process_instance_id` when calling `message_event_received`")  # noqa: E501
        # verify the required parameter 'message_name' is set
        if ('message_name' not in params or
                params['message_name'] is None):
            raise ValueError("Missing the required parameter `message_name` when calling `message_event_received`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'process_instance_id' in params:
            path_params['processInstanceId'] = params['process_instance_id']  # noqa: E501
        if 'message_name' in params:
            path_params['messageName'] = params['message_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances/{processInstanceId}/messageEvents/{messageName}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_workflow_instances(self, **kwargs):  # noqa: E501
        """Start workflow instances.  # noqa: E501

        Starts multiple workflow instances based on the provided request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_workflow_instances(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StartWorkflowInstancesRequest body: The properties of the workflow to be started.
        :return: list[WorkflowInstance]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.start_workflow_instances_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.start_workflow_instances_with_http_info(**kwargs)  # noqa: E501
            return data

    def start_workflow_instances_with_http_info(self, **kwargs):  # noqa: E501
        """Start workflow instances.  # noqa: E501

        Starts multiple workflow instances based on the provided request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_workflow_instances_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StartWorkflowInstancesRequest body: The properties of the workflow to be started.
        :return: list[WorkflowInstance]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_workflow_instances" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[WorkflowInstance]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_workflow_instances_in_job(self, **kwargs):  # noqa: E501
        """Start workflow instances.  # noqa: E501

        Starts multiple workflow instances asynchronously based on the provided request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_workflow_instances_in_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StartWorkflowInstancesRequest body: Properties of the workflow to be started.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.start_workflow_instances_in_job_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.start_workflow_instances_in_job_with_http_info(**kwargs)  # noqa: E501
            return data

    def start_workflow_instances_in_job_with_http_info(self, **kwargs):  # noqa: E501
        """Start workflow instances.  # noqa: E501

        Starts multiple workflow instances asynchronously based on the provided request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_workflow_instances_in_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StartWorkflowInstancesRequest body: Properties of the workflow to be started.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_workflow_instances_in_job" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowInstances/startJobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.issues_api import IssuesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestIssuesApi(unittest.TestCase):
    """IssuesApi unit test stubs"""

    def setUp(self):
        self.api = IssuesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_issue(self):
        """Test case for add_issue

        Adds a new issue.  # noqa: E501
        """
        pass

    def test_find_issues(self):
        """Test case for find_issues

        Returns issues matching the given search criteria.  # noqa: E501
        """
        pass

    def test_move_issue(self):
        """Test case for move_issue

        Moves an issue to another community.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class ComplexRelationsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_complex_relation(self, **kwargs):  # noqa: E501
        """Adds new complex relation.  # noqa: E501

        Adds new complex relation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_complex_relation(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddComplexRelationRequest body:
        :return: ComplexRelationImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_complex_relation_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_complex_relation_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_complex_relation_with_http_info(self, **kwargs):  # noqa: E501
        """Adds new complex relation.  # noqa: E501

        Adds new complex relation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_complex_relation_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddComplexRelationRequest body:
        :return: ComplexRelationImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_complex_relation" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/complexRelations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ComplexRelationImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_complex_relation(self, complex_relation_id, **kwargs):  # noqa: E501
        """Change the complex relation with the information that is present in the request.  # noqa: E501

        Change the complex relation with the information that is present in the request.  Only properties that are specified in this request and have not <code>null</code> values are updated.  All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_complex_relation(complex_relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str complex_relation_id: the id of the complex relation to be modified. (required)
        :param ChangeComplexRelationRequest body:
        :return: ComplexRelationImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_complex_relation_with_http_info(complex_relation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_complex_relation_with_http_info(complex_relation_id, **kwargs)  # noqa: E501
            return data

    def change_complex_relation_with_http_info(self, complex_relation_id, **kwargs):  # noqa: E501
        """Change the complex relation with the information that is present in the request.  # noqa: E501

        Change the complex relation with the information that is present in the request.  Only properties that are specified in this request and have not <code>null</code> values are updated.  All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_complex_relation_with_http_info(complex_relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str complex_relation_id: the id of the complex relation to be modified. (required)
        :param ChangeComplexRelationRequest body:
        :return: ComplexRelationImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['complex_relation_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_complex_relation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'complex_relation_id' is set
        if ('complex_relation_id' not in params or
                params['complex_relation_id'] is None):
            raise ValueError("Missing the required parameter `complex_relation_id` when calling `change_complex_relation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'complex_relation_id' in params:
            path_params['complexRelationId'] = params['complex_relation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/complexRelations/{complexRelationId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ComplexRelationImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_to_csv(self, **kwargs):  # noqa: E501
        """Export complex relations of the given type to CSV.  # noqa: E501

        Export complex relations of the given type to CSV.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_to_csv(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExportComplexRelationsToCSVRequest body:
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.export_to_csv_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.export_to_csv_with_http_info(**kwargs)  # noqa: E501
            return data

    def export_to_csv_with_http_info(self, **kwargs):  # noqa: E501
        """Export complex relations of the given type to CSV.  # noqa: E501

        Export complex relations of the given type to CSV.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_to_csv_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExportComplexRelationsToCSVRequest body:
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_to_csv" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/complexRelations/export/csv-job', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_to_csv_without_job(self, **kwargs):  # noqa: E501
        """Export all complex relations of the given type to a CSV file.  # noqa: E501

        Export all complex relations of the given type to a CSV file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_to_csv_without_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExportComplexRelationsToCSVRequest body:
        :return: FileInfoImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.export_to_csv_without_job_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.export_to_csv_without_job_with_http_info(**kwargs)  # noqa: E501
            return data

    def export_to_csv_without_job_with_http_info(self, **kwargs):  # noqa: E501
        """Export all complex relations of the given type to a CSV file.  # noqa: E501

        Export all complex relations of the given type to a CSV file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_to_csv_without_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExportComplexRelationsToCSVRequest body:
        :return: FileInfoImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_to_csv_without_job" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/complexRelations/export/csv-file', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileInfoImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_to_csvas_string(self, **kwargs):  # noqa: E501
        """Export all complex relations of the given type to CSV as a String.  # noqa: E501

        Export all complex relations of the given type to CSV as a String.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_to_csvas_string(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExportComplexRelationsToCSVRequest body:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.export_to_csvas_string_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.export_to_csvas_string_with_http_info(**kwargs)  # noqa: E501
            return data

    def export_to_csvas_string_with_http_info(self, **kwargs):  # noqa: E501
        """Export all complex relations of the given type to CSV as a String.  # noqa: E501

        Export all complex relations of the given type to CSV as a String.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_to_csvas_string_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExportComplexRelationsToCSVRequest body:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_to_csvas_string" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/complexRelations/export/csv', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_to_excel(self, **kwargs):  # noqa: E501
        """Export complex relations of the given type to Excel.  # noqa: E501

        Export complex relations of the given type to Excel.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_to_excel(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExportComplexRelationsToExcelRequest body:
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.export_to_excel_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.export_to_excel_with_http_info(**kwargs)  # noqa: E501
            return data

    def export_to_excel_with_http_info(self, **kwargs):  # noqa: E501
        """Export complex relations of the given type to Excel.  # noqa: E501

        Export complex relations of the given type to Excel.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_to_excel_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExportComplexRelationsToExcelRequest body:
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_to_excel" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/complexRelations/export/excel-job', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_to_excel_without_job(self, **kwargs):  # noqa: E501
        """Export all complex relations of the given type to an Excel file.  # noqa: E501

        Export all complex relations of the given type to an Excel file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_to_excel_without_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExportComplexRelationsToExcelRequest body:
        :return: FileInfoImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.export_to_excel_without_job_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.export_to_excel_without_job_with_http_info(**kwargs)  # noqa: E501
            return data

    def export_to_excel_without_job_with_http_info(self, **kwargs):  # noqa: E501
        """Export all complex relations of the given type to an Excel file.  # noqa: E501

        Export all complex relations of the given type to an Excel file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_to_excel_without_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ExportComplexRelationsToExcelRequest body:
        :return: FileInfoImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_to_excel_without_job" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/complexRelations/export/excel-file', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileInfoImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_complex_relations(self, **kwargs):  # noqa: E501
        """Returns complex relations matching the given search criteria.  # noqa: E501

        Returns complex relations matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering.  All other parameters are ignored.  The returned complex relations satisfy all constraints that are specified in this search criteria.  By default a result containing 1000 complex relations is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_complex_relations(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>. Cursor should be preferred over offset for better performance and stable results. It is forbidden to use both in the same request.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped. For cursor pagination this parameter is ignored and count is skipped.
        :param str cursor: Cursor for the current page of results. To retrieve the first page with cursor pagination you need to pass this parameter with an empty value (must be non-null). For the next pages, the value must be taken from the response (<code>nextCursor</code> property).
        :param str asset_id: The ID of the asset for which complex relations should be found.
        :param str type_id: The ID of the type of complex relations to search for.
        :return: ComplexRelationPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_complex_relations_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_complex_relations_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_complex_relations_with_http_info(self, **kwargs):  # noqa: E501
        """Returns complex relations matching the given search criteria.  # noqa: E501

        Returns complex relations matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering.  All other parameters are ignored.  The returned complex relations satisfy all constraints that are specified in this search criteria.  By default a result containing 1000 complex relations is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_complex_relations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>. Cursor should be preferred over offset for better performance and stable results. It is forbidden to use both in the same request.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped. For cursor pagination this parameter is ignored and count is skipped.
        :param str cursor: Cursor for the current page of results. To retrieve the first page with cursor pagination you need to pass this parameter with an empty value (must be non-null). For the next pages, the value must be taken from the response (<code>nextCursor</code> property).
        :param str asset_id: The ID of the asset for which complex relations should be found.
        :param str type_id: The ID of the type of complex relations to search for.
        :return: ComplexRelationPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit', 'cursor', 'asset_id', 'type_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_complex_relations" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'cursor' in params:
            query_params.append(('cursor', params['cursor']))  # noqa: E501
        if 'asset_id' in params:
            query_params.append(('assetId', params['asset_id']))  # noqa: E501
        if 'type_id' in params:
            query_params.append(('typeId', params['type_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/complexRelations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ComplexRelationPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_complex_relation(self, complex_relation_id, **kwargs):  # noqa: E501
        """Returns a ComplexRelation identified by given id.  # noqa: E501

        Returns a complex relation identified by given <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_complex_relation(complex_relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str complex_relation_id: the id of the complex relation. (required)
        :return: ComplexRelationImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_complex_relation_with_http_info(complex_relation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_complex_relation_with_http_info(complex_relation_id, **kwargs)  # noqa: E501
            return data

    def get_complex_relation_with_http_info(self, complex_relation_id, **kwargs):  # noqa: E501
        """Returns a ComplexRelation identified by given id.  # noqa: E501

        Returns a complex relation identified by given <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_complex_relation_with_http_info(complex_relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str complex_relation_id: the id of the complex relation. (required)
        :return: ComplexRelationImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['complex_relation_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_complex_relation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'complex_relation_id' is set
        if ('complex_relation_id' not in params or
                params['complex_relation_id'] is None):
            raise ValueError("Missing the required parameter `complex_relation_id` when calling `get_complex_relation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'complex_relation_id' in params:
            path_params['complexRelationId'] = params['complex_relation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/complexRelations/{complexRelationId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ComplexRelationImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_complex_relation(self, complex_relation_id, **kwargs):  # noqa: E501
        """Removes complex relation identified by given id.  # noqa: E501

        Removes complex relation identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_complex_relation(complex_relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str complex_relation_id: the id of the complex relation to be removed. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_complex_relation_with_http_info(complex_relation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_complex_relation_with_http_info(complex_relation_id, **kwargs)  # noqa: E501
            return data

    def remove_complex_relation_with_http_info(self, complex_relation_id, **kwargs):  # noqa: E501
        """Removes complex relation identified by given id.  # noqa: E501

        Removes complex relation identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_complex_relation_with_http_info(complex_relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str complex_relation_id: the id of the complex relation to be removed. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['complex_relation_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_complex_relation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'complex_relation_id' is set
        if ('complex_relation_id' not in params or
                params['complex_relation_id'] is None):
            raise ValueError("Missing the required parameter `complex_relation_id` when calling `remove_complex_relation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'complex_relation_id' in params:
            path_params['complexRelationId'] = params['complex_relation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/complexRelations/{complexRelationId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddAssetTypeRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'public_id': 'str',
        'name': 'str',
        'description': 'str',
        'color': 'str',
        'symbol_type': 'str',
        'icon_code': 'str',
        'acronym_code': 'str',
        'parent_id': 'str',
        'display_name_enabled': 'bool',
        'rating_enabled': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'public_id': 'publicId',
        'name': 'name',
        'description': 'description',
        'color': 'color',
        'symbol_type': 'symbolType',
        'icon_code': 'iconCode',
        'acronym_code': 'acronymCode',
        'parent_id': 'parentId',
        'display_name_enabled': 'displayNameEnabled',
        'rating_enabled': 'ratingEnabled'
    }

    def __init__(self, id=None, public_id=None, name=None, description=None, color=None, symbol_type=None, icon_code=None, acronym_code=None, parent_id=None, display_name_enabled=None, rating_enabled=None):  # noqa: E501
        """AddAssetTypeRequest - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._public_id = None
        self._name = None
        self._description = None
        self._color = None
        self._symbol_type = None
        self._icon_code = None
        self._acronym_code = None
        self._parent_id = None
        self._display_name_enabled = None
        self._rating_enabled = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if public_id is not None:
            self.public_id = public_id
        self.name = name
        if description is not None:
            self.description = description
        if color is not None:
            self.color = color
        self.symbol_type = symbol_type
        if icon_code is not None:
            self.icon_code = icon_code
        if acronym_code is not None:
            self.acronym_code = acronym_code
        if parent_id is not None:
            self.parent_id = parent_id
        self.display_name_enabled = display_name_enabled
        self.rating_enabled = rating_enabled

    @property
    def id(self):
        """Gets the id of this AddAssetTypeRequest.  # noqa: E501

        The UUID that will be assigned to the new Asset Type. It should be unique within all Asset Types, and should not start with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :return: The id of this AddAssetTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AddAssetTypeRequest.

        The UUID that will be assigned to the new Asset Type. It should be unique within all Asset Types, and should not start with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :param id: The id of this AddAssetTypeRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def public_id(self):
        """Gets the public_id of this AddAssetTypeRequest.  # noqa: E501

        The public id that will be assigned to the new Asset Type. It must be unique within all Asset Types, Complex Relation Types, Domain Types and Scopes. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". If no public id is provided, a valid public id will be generated.  # noqa: E501

        :return: The public_id of this AddAssetTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._public_id

    @public_id.setter
    def public_id(self, public_id):
        """Sets the public_id of this AddAssetTypeRequest.

        The public id that will be assigned to the new Asset Type. It must be unique within all Asset Types, Complex Relation Types, Domain Types and Scopes. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". If no public id is provided, a valid public id will be generated.  # noqa: E501

        :param public_id: The public_id of this AddAssetTypeRequest.  # noqa: E501
        :type: str
        """

        self._public_id = public_id

    @property
    def name(self):
        """Gets the name of this AddAssetTypeRequest.  # noqa: E501

        The name of the new Asset Type. Should be unique within all Asset Types.  # noqa: E501

        :return: The name of this AddAssetTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AddAssetTypeRequest.

        The name of the new Asset Type. Should be unique within all Asset Types.  # noqa: E501

        :param name: The name of this AddAssetTypeRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this AddAssetTypeRequest.  # noqa: E501

        The description of the new Asset Type.  # noqa: E501

        :return: The description of this AddAssetTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AddAssetTypeRequest.

        The description of the new Asset Type.  # noqa: E501

        :param description: The description of this AddAssetTypeRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def color(self):
        """Gets the color of this AddAssetTypeRequest.  # noqa: E501

        The color of the symbol in hex format.  # noqa: E501

        :return: The color of this AddAssetTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this AddAssetTypeRequest.

        The color of the symbol in hex format.  # noqa: E501

        :param color: The color of this AddAssetTypeRequest.  # noqa: E501
        :type: str
        """

        self._color = color

    @property
    def symbol_type(self):
        """Gets the symbol_type of this AddAssetTypeRequest.  # noqa: E501

        The symbol type.  # noqa: E501

        :return: The symbol_type of this AddAssetTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._symbol_type

    @symbol_type.setter
    def symbol_type(self, symbol_type):
        """Sets the symbol_type of this AddAssetTypeRequest.

        The symbol type.  # noqa: E501

        :param symbol_type: The symbol_type of this AddAssetTypeRequest.  # noqa: E501
        :type: str
        """
        if symbol_type is None:
            raise ValueError("Invalid value for `symbol_type`, must not be `None`")  # noqa: E501
        allowed_values = ["NONE", "ICON_CODE", "ACRONYM_CODE"]  # noqa: E501
        if symbol_type not in allowed_values:
            raise ValueError(
                "Invalid value for `symbol_type` ({0}), must be one of {1}"  # noqa: E501
                .format(symbol_type, allowed_values)
            )

        self._symbol_type = symbol_type

    @property
    def icon_code(self):
        """Gets the icon_code of this AddAssetTypeRequest.  # noqa: E501

        The icon code, a code representing the icon that should be shown.  # noqa: E501

        :return: The icon_code of this AddAssetTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._icon_code

    @icon_code.setter
    def icon_code(self, icon_code):
        """Sets the icon_code of this AddAssetTypeRequest.

        The icon code, a code representing the icon that should be shown.  # noqa: E501

        :param icon_code: The icon_code of this AddAssetTypeRequest.  # noqa: E501
        :type: str
        """

        self._icon_code = icon_code

    @property
    def acronym_code(self):
        """Gets the acronym_code of this AddAssetTypeRequest.  # noqa: E501

        A code representing the acronym that should be shown.  # noqa: E501

        :return: The acronym_code of this AddAssetTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._acronym_code

    @acronym_code.setter
    def acronym_code(self, acronym_code):
        """Sets the acronym_code of this AddAssetTypeRequest.

        A code representing the acronym that should be shown.  # noqa: E501

        :param acronym_code: The acronym_code of this AddAssetTypeRequest.  # noqa: E501
        :type: str
        """

        self._acronym_code = acronym_code

    @property
    def parent_id(self):
        """Gets the parent_id of this AddAssetTypeRequest.  # noqa: E501

        The ID of the parent for the new Asset Type.  # noqa: E501

        :return: The parent_id of this AddAssetTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this AddAssetTypeRequest.

        The ID of the parent for the new Asset Type.  # noqa: E501

        :param parent_id: The parent_id of this AddAssetTypeRequest.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def display_name_enabled(self):
        """Gets the display_name_enabled of this AddAssetTypeRequest.  # noqa: E501

        Whether the display name should be enabled for all Assets of the type being created.  # noqa: E501

        :return: The display_name_enabled of this AddAssetTypeRequest.  # noqa: E501
        :rtype: bool
        """
        return self._display_name_enabled

    @display_name_enabled.setter
    def display_name_enabled(self, display_name_enabled):
        """Sets the display_name_enabled of this AddAssetTypeRequest.

        Whether the display name should be enabled for all Assets of the type being created.  # noqa: E501

        :param display_name_enabled: The display_name_enabled of this AddAssetTypeRequest.  # noqa: E501
        :type: bool
        """
        if display_name_enabled is None:
            raise ValueError("Invalid value for `display_name_enabled`, must not be `None`")  # noqa: E501

        self._display_name_enabled = display_name_enabled

    @property
    def rating_enabled(self):
        """Gets the rating_enabled of this AddAssetTypeRequest.  # noqa: E501

        Whether ratings should be enabled for all Assets of the type being created.  # noqa: E501

        :return: The rating_enabled of this AddAssetTypeRequest.  # noqa: E501
        :rtype: bool
        """
        return self._rating_enabled

    @rating_enabled.setter
    def rating_enabled(self, rating_enabled):
        """Sets the rating_enabled of this AddAssetTypeRequest.

        Whether ratings should be enabled for all Assets of the type being created.  # noqa: E501

        :param rating_enabled: The rating_enabled of this AddAssetTypeRequest.  # noqa: E501
        :type: bool
        """
        if rating_enabled is None:
            raise ValueError("Invalid value for `rating_enabled`, must not be `None`")  # noqa: E501

        self._rating_enabled = rating_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddAssetTypeRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddAssetTypeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.attributes_api import AttributesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestAttributesApi(unittest.TestCase):
    """AttributesApi unit test stubs"""

    def setUp(self):
        self.api = AttributesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_attribute(self):
        """Test case for add_attribute

        Add attribute  # noqa: E501
        """
        pass

    def test_add_attributes(self):
        """Test case for add_attributes

        Add attributes  # noqa: E501
        """
        pass

    def test_change_attribute(self):
        """Test case for change_attribute

        Change attribute  # noqa: E501
        """
        pass

    def test_change_attributes(self):
        """Test case for change_attributes

        Change attributes  # noqa: E501
        """
        pass

    def test_find_attributes(self):
        """Test case for find_attributes

        Find attributes  # noqa: E501
        """
        pass

    def test_get_attribute(self):
        """Test case for get_attribute

        Get attribute  # noqa: E501
        """
        pass

    def test_remove_attribute(self):
        """Test case for remove_attribute

        Remove attribute  # noqa: E501
        """
        pass

    def test_remove_attributes(self):
        """Test case for remove_attributes

        Remove attributes  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class AttributeTypesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_attribute_type(self, **kwargs):  # noqa: E501
        """Adds a new Attribute Type.  # noqa: E501

        Adds a new Attribute Type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_attribute_type(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddAttributeTypeRequest body:
        :return: AttributeType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_attribute_type_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_attribute_type_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_attribute_type_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a new Attribute Type.  # noqa: E501

        Adds a new Attribute Type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_attribute_type_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddAttributeTypeRequest body:
        :return: AttributeType
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_attribute_type" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributeTypes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttributeType',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_attribute_types(self, **kwargs):  # noqa: E501
        """Adds multiple Attribute Types.  # noqa: E501

        Adds multiple Attribute Types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_attribute_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[AddAttributeTypeRequest] body:
        :return: list[AttributeType]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_attribute_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_attribute_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_attribute_types_with_http_info(self, **kwargs):  # noqa: E501
        """Adds multiple Attribute Types.  # noqa: E501

        Adds multiple Attribute Types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_attribute_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[AddAttributeTypeRequest] body:
        :return: list[AttributeType]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_attribute_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributeTypes/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AttributeType]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_attribute_type(self, attribute_type_id, **kwargs):  # noqa: E501
        """Changes the attribute types.  # noqa: E501

        Changes the attribute types with the information present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_attribute_type(attribute_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attribute_type_id: the unique identifier of the attribute type (required)
        :param ChangeAttributeTypeRequest body:
        :return: AttributeType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_attribute_type_with_http_info(attribute_type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_attribute_type_with_http_info(attribute_type_id, **kwargs)  # noqa: E501
            return data

    def change_attribute_type_with_http_info(self, attribute_type_id, **kwargs):  # noqa: E501
        """Changes the attribute types.  # noqa: E501

        Changes the attribute types with the information present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_attribute_type_with_http_info(attribute_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attribute_type_id: the unique identifier of the attribute type (required)
        :param ChangeAttributeTypeRequest body:
        :return: AttributeType
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['attribute_type_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_attribute_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'attribute_type_id' is set
        if ('attribute_type_id' not in params or
                params['attribute_type_id'] is None):
            raise ValueError("Missing the required parameter `attribute_type_id` when calling `change_attribute_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attribute_type_id' in params:
            path_params['attributeTypeId'] = params['attribute_type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributeTypes/{attributeTypeId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttributeType',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_attribute_types(self, **kwargs):  # noqa: E501
        """Changes multiple attribute types.  # noqa: E501

        Changes multiple attribute types with the information present in the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_attribute_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeAttributeTypeRequest] body:
        :return: list[AttributeType]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_attribute_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.change_attribute_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def change_attribute_types_with_http_info(self, **kwargs):  # noqa: E501
        """Changes multiple attribute types.  # noqa: E501

        Changes multiple attribute types with the information present in the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_attribute_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeAttributeTypeRequest] body:
        :return: list[AttributeType]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_attribute_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributeTypes/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AttributeType]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_attribute_types(self, **kwargs):  # noqa: E501
        """Returns attribute types matching the given search criteria.  # noqa: E501

        Returns attribute types matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned attribute types satisfy all constraints that are specified in this search criteria. By default a result containing 1000 attribute types is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_attribute_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str name: The name of the Attribute Type to search for.
        :param str name_match_mode: The match mode used to compare <code>name</code>. If the match mode is <code>EXACT</code> the search is case-sensitive, otherwise the search is case-insensitive.
        :param str kind: The kind of the Attribute Type to search for.
        :param str language: The language of the Attribute Type to search for. This property is only applicable to Attribute Types of kind \"Script\".
        :param bool statistics_enabled: Whether the Attribute Types should be searched with statistics enabled or not. This property is only applicable to Attribute Types of kind \"Numeric\" or \"Boolean\".
        :param bool is_integer: Whether only integer-type Attribute Types should be searched or not. This property is only applicable to Attribute Types of kind \"Numeric\".
        :param str sort_field: The field that should be used as reference for sorting.
        :param str sort_order: The order of sorting.
        :return: AttributeTypePagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_attribute_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_attribute_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_attribute_types_with_http_info(self, **kwargs):  # noqa: E501
        """Returns attribute types matching the given search criteria.  # noqa: E501

        Returns attribute types matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned attribute types satisfy all constraints that are specified in this search criteria. By default a result containing 1000 attribute types is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_attribute_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str name: The name of the Attribute Type to search for.
        :param str name_match_mode: The match mode used to compare <code>name</code>. If the match mode is <code>EXACT</code> the search is case-sensitive, otherwise the search is case-insensitive.
        :param str kind: The kind of the Attribute Type to search for.
        :param str language: The language of the Attribute Type to search for. This property is only applicable to Attribute Types of kind \"Script\".
        :param bool statistics_enabled: Whether the Attribute Types should be searched with statistics enabled or not. This property is only applicable to Attribute Types of kind \"Numeric\" or \"Boolean\".
        :param bool is_integer: Whether only integer-type Attribute Types should be searched or not. This property is only applicable to Attribute Types of kind \"Numeric\".
        :param str sort_field: The field that should be used as reference for sorting.
        :param str sort_order: The order of sorting.
        :return: AttributeTypePagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit', 'name', 'name_match_mode', 'kind', 'language', 'statistics_enabled', 'is_integer', 'sort_field', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_attribute_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'name_match_mode' in params:
            query_params.append(('nameMatchMode', params['name_match_mode']))  # noqa: E501
        if 'kind' in params:
            query_params.append(('kind', params['kind']))  # noqa: E501
        if 'language' in params:
            query_params.append(('language', params['language']))  # noqa: E501
        if 'statistics_enabled' in params:
            query_params.append(('statisticsEnabled', params['statistics_enabled']))  # noqa: E501
        if 'is_integer' in params:
            query_params.append(('isInteger', params['is_integer']))  # noqa: E501
        if 'sort_field' in params:
            query_params.append(('sortField', params['sort_field']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributeTypes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttributeTypePagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attribute_type(self, attribute_type_id, **kwargs):  # noqa: E501
        """Returns the attribute type identified by given UUID.  # noqa: E501

        Returns the attribute type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attribute_type(attribute_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attribute_type_id: the unique identifier of the attribute type (required)
        :return: AttributeType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_attribute_type_with_http_info(attribute_type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_attribute_type_with_http_info(attribute_type_id, **kwargs)  # noqa: E501
            return data

    def get_attribute_type_with_http_info(self, attribute_type_id, **kwargs):  # noqa: E501
        """Returns the attribute type identified by given UUID.  # noqa: E501

        Returns the attribute type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attribute_type_with_http_info(attribute_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attribute_type_id: the unique identifier of the attribute type (required)
        :return: AttributeType
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['attribute_type_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attribute_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'attribute_type_id' is set
        if ('attribute_type_id' not in params or
                params['attribute_type_id'] is None):
            raise ValueError("Missing the required parameter `attribute_type_id` when calling `get_attribute_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attribute_type_id' in params:
            path_params['attributeTypeId'] = params['attribute_type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributeTypes/{attributeTypeId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttributeType',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attribute_type_by_name(self, attribute_type_name, **kwargs):  # noqa: E501
        """Returns the attribute type identified by given name.  # noqa: E501

        Returns the attribute type identified by given name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attribute_type_by_name(attribute_type_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attribute_type_name: the unique identifier of the attribute type (required)
        :return: AttributeType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_attribute_type_by_name_with_http_info(attribute_type_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_attribute_type_by_name_with_http_info(attribute_type_name, **kwargs)  # noqa: E501
            return data

    def get_attribute_type_by_name_with_http_info(self, attribute_type_name, **kwargs):  # noqa: E501
        """Returns the attribute type identified by given name.  # noqa: E501

        Returns the attribute type identified by given name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attribute_type_by_name_with_http_info(attribute_type_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attribute_type_name: the unique identifier of the attribute type (required)
        :return: AttributeType
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['attribute_type_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attribute_type_by_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'attribute_type_name' is set
        if ('attribute_type_name' not in params or
                params['attribute_type_name'] is None):
            raise ValueError("Missing the required parameter `attribute_type_name` when calling `get_attribute_type_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attribute_type_name' in params:
            path_params['attributeTypeName'] = params['attribute_type_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributeTypes/name/{attributeTypeName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttributeType',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_attribute_type(self, attribute_type_id, **kwargs):  # noqa: E501
        """Removes attribute type identified by given UUID.  # noqa: E501

        Removes attribute type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_attribute_type(attribute_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attribute_type_id: the unique identifier of the attribute type (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_attribute_type_with_http_info(attribute_type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_attribute_type_with_http_info(attribute_type_id, **kwargs)  # noqa: E501
            return data

    def remove_attribute_type_with_http_info(self, attribute_type_id, **kwargs):  # noqa: E501
        """Removes attribute type identified by given UUID.  # noqa: E501

        Removes attribute type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_attribute_type_with_http_info(attribute_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str attribute_type_id: the unique identifier of the attribute type (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['attribute_type_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_attribute_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'attribute_type_id' is set
        if ('attribute_type_id' not in params or
                params['attribute_type_id'] is None):
            raise ValueError("Missing the required parameter `attribute_type_id` when calling `remove_attribute_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attribute_type_id' in params:
            path_params['attributeTypeId'] = params['attribute_type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributeTypes/{attributeTypeId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_attribute_types(self, **kwargs):  # noqa: E501
        """Removes multiple attribute types.  # noqa: E501

        Removes multiple attribute types identified by the UUIDs passed as parameter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_attribute_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_attribute_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.remove_attribute_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def remove_attribute_types_with_http_info(self, **kwargs):  # noqa: E501
        """Removes multiple attribute types.  # noqa: E501

        Removes multiple attribute types identified by the UUIDs passed as parameter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_attribute_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_attribute_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attributeTypes/bulk', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class CommentsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_comment(self, **kwargs):  # noqa: E501
        """Add comment.  # noqa: E501

        Adds a new comment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_comment(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddCommentRequest body: The properties of new comment.
        :return: Comment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_comment_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_comment_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_comment_with_http_info(self, **kwargs):  # noqa: E501
        """Add comment.  # noqa: E501

        Adds a new comment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_comment_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddCommentRequest body: The properties of new comment.
        :return: Comment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_comment" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/comments', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Comment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_comment(self, comment_id, **kwargs):  # noqa: E501
        """Change comment.  # noqa: E501

        <p>Modifies the comment with the specified ID.</p><p>Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_comment(comment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str comment_id: The ID of the comment to be changed. (required)
        :param ChangeCommentRequest body: The properties to change comment.
        :return: Comment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_comment_with_http_info(comment_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_comment_with_http_info(comment_id, **kwargs)  # noqa: E501
            return data

    def change_comment_with_http_info(self, comment_id, **kwargs):  # noqa: E501
        """Change comment.  # noqa: E501

        <p>Modifies the comment with the specified ID.</p><p>Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_comment_with_http_info(comment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str comment_id: The ID of the comment to be changed. (required)
        :param ChangeCommentRequest body: The properties to change comment.
        :return: Comment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['comment_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_comment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'comment_id' is set
        if ('comment_id' not in params or
                params['comment_id'] is None):
            raise ValueError("Missing the required parameter `comment_id` when calling `change_comment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'comment_id' in params:
            path_params['commentId'] = params['comment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/comments/{commentId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Comment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_comments(self, **kwargs):  # noqa: E501
        """Find comments.  # noqa: E501

        <p>Returns comments matching the given search criteria.</p><p>Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored.</p><p>The returned comments satisfy all constraints that are specified in this search criteria.</p><p>By default, the result contains up to 1000 comments.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_comments(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str parent_id: The ID of the comment which the reply comments should be searched for
        :param str user_id: The ID of the user who created the comment.
        :param str base_resource_id: The ID of the resource which the searched comments refer to.
        :param bool root_comment: Whether the searched comments should be root comments (not reply comments).
        :param str sort_order: The order of sorting on the date the comment was created.
        :return: CommentPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_comments_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_comments_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_comments_with_http_info(self, **kwargs):  # noqa: E501
        """Find comments.  # noqa: E501

        <p>Returns comments matching the given search criteria.</p><p>Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored.</p><p>The returned comments satisfy all constraints that are specified in this search criteria.</p><p>By default, the result contains up to 1000 comments.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_comments_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str parent_id: The ID of the comment which the reply comments should be searched for
        :param str user_id: The ID of the user who created the comment.
        :param str base_resource_id: The ID of the resource which the searched comments refer to.
        :param bool root_comment: Whether the searched comments should be root comments (not reply comments).
        :param str sort_order: The order of sorting on the date the comment was created.
        :return: CommentPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit', 'parent_id', 'user_id', 'base_resource_id', 'root_comment', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_comments" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'parent_id' in params:
            query_params.append(('parentId', params['parent_id']))  # noqa: E501
        if 'user_id' in params:
            query_params.append(('userId', params['user_id']))  # noqa: E501
        if 'base_resource_id' in params:
            query_params.append(('baseResourceId', params['base_resource_id']))  # noqa: E501
        if 'root_comment' in params:
            query_params.append(('rootComment', params['root_comment']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/comments', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CommentPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_comment(self, comment_id, **kwargs):  # noqa: E501
        """Get comment.  # noqa: E501

        Returns the comment with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_comment(comment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str comment_id: The ID of the comment. (required)
        :return: Comment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_comment_with_http_info(comment_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_comment_with_http_info(comment_id, **kwargs)  # noqa: E501
            return data

    def get_comment_with_http_info(self, comment_id, **kwargs):  # noqa: E501
        """Get comment.  # noqa: E501

        Returns the comment with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_comment_with_http_info(comment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str comment_id: The ID of the comment. (required)
        :return: Comment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['comment_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_comment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'comment_id' is set
        if ('comment_id' not in params or
                params['comment_id'] is None):
            raise ValueError("Missing the required parameter `comment_id` when calling `get_comment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'comment_id' in params:
            path_params['commentId'] = params['comment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/comments/{commentId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Comment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_comment(self, comment_id, **kwargs):  # noqa: E501
        """Remove comment.  # noqa: E501

        Removes the comment with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_comment(comment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str comment_id: The ID of the comment to be removed. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_comment_with_http_info(comment_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_comment_with_http_info(comment_id, **kwargs)  # noqa: E501
            return data

    def remove_comment_with_http_info(self, comment_id, **kwargs):  # noqa: E501
        """Remove comment.  # noqa: E501

        Removes the comment with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_comment_with_http_info(comment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str comment_id: The ID of the comment to be removed. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['comment_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_comment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'comment_id' is set
        if ('comment_id' not in params or
                params['comment_id'] is None):
            raise ValueError("Missing the required parameter `comment_id` when calling `remove_comment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'comment_id' in params:
            path_params['commentId'] = params['comment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/comments/{commentId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
